@@ -449,7 +449,8 @@ def get_fruchterman_reingold_layout(edges,
         fixed_node_sizes = np.array([])
 
     if k is None:
-        area = np.product(scale)
+        # area = np.product(scale)
+        area = np.pi * (min(scale) / 2) ** 2
         k = np.sqrt(area / float(total_nodes))
 
     temperatures = _get_temperature_decay(initial_temperature, total_iterations)
@@ -1690,13 +1691,13 @@ def get_geometric_layout(edges, edge_length, node_size=0., tol=1e-3, origin=(0,
     ----------
     edges : list
         The edges of the graph, with each edge being represented by a (source node ID, target node ID) tuple.
-    edge_lengths : dict
+    edge_length : dict
         Mapping of edges to their lengths.
     node_size : scalar or dict, default 0.
         Size (radius) of nodes.
         Providing the correct node size minimises the overlap of nodes in the graph,
         which can otherwise occur if there are many nodes, or if the nodes differ considerably in size.
-    tolerance : float, default 1e-3
+    tol : float, default 1e-3
         The tolerance of the cost function. Small values increase the accuracy, large values improve the computation time.
     origin : tuple, default (0, 0)
         The (float x, float y) coordinates corresponding to the lower left hand corner of the bounding box specifying the extent of the canvas.
